isShow property
bool
get
isShow
Returns true if the popup menu is currently visible.
Implementation
bool get isShow => _isShow;
Returns true if the popup menu is currently visible.
bool get isShow => _isShow;